@@ -120,7 +120,7 @@ class Connection(object):
         password = password
         database = database
         port = port
-        scheme = scheme
+        scheme = "e6xdb"
 
         if scheme != "e6xdb":
             raise ValueError("scheme is not e6xdb")
@@ -326,6 +326,22 @@ class Error(Exception):
     pass
 
 
+if __name__ == '__main__':
+    connection = connect(host="localhost",
+                         port=9000,
+                         scheme="e6xdb",
+                         username="admin",
+                         database="./input/tpcds_330mb",
+                         auth=None,
+                         configuration=None,
+                         kerberos_service_name=None,
+                         password="admin",
+                         check_hostname=None,
+                         ssl_cert=None,
+                         thrift_transport=None)
+    cursor = Cursor(connection)
+    cursor.execute("select * from date_dim")
+    data = cursor.fetchall()
 #
 # Type Objects and Constructors
 #
